@@ -69,7 +69,8 @@ impl Session {
             incoming_err_sender: Arc::new(err_sender),
             endpoint,
             network: Arc::new(NetworkPrefixMap::new(genesis_key)),
-            ae_cache: Arc::new(RwLock::new(AeCache::default())),
+            ae_redirect_cache: Arc::new(RwLock::new(AeCache::default())),
+            ae_retry_cache: Arc::new(RwLock::new(AeCache::default())),
             aggregator: Arc::new(RwLock::new(SignatureAggregator::new())),
             bootstrap_peer: bootstrap_peer.remote_address(),
             genesis_key,
@@ -243,7 +244,7 @@ impl Session {
         if let Ok(op_id) = query.operation_id() {
             let _ = tokio::spawn(async move {
                 // Insert the response sender
-                trace!("Inserting channel for {:?}", op_id);
+                trace!("Inserting channel for op_id {:?}", op_id);
                 let _old = pending_queries_for_thread
                     .write()
                     .await
@@ -473,7 +474,7 @@ pub(crate) async fn send_message(
 
             *successes_clone.write().await += 1;
 
-            trace!("Sent cmd with MsgId {:?} to {:?}", msg_id, &socket);
+            trace!("Sent msg with MsgId {:?} to {:?}", msg_id, &socket);
             Ok(())
         });
         tasks.push(task_handle);
@@ -482,7 +483,6 @@ pub(crate) async fn send_message(
     // Let's await for all messages to be sent
     let _ = join_all(tasks).await;
 
-    // anything not concretely registered as success here is a failure
     let failures = elders.len() - *successes.read().await;
 
     if failures > 0 {
